@@ -181,8 +181,6 @@ void Account::Private::on_enabled(Account *self, const gchar *service_name,
 
 void Account::Private::on_deleted(Account *self)
 {
-    TRACE();
-
     Q_EMIT self->removed();
 }
 
@@ -487,7 +485,7 @@ QStringList Account::childGroups() const
     QStringList groups, all_keys;
 
     all_keys = allKeys();
-    Q_FOREACH (QString key, all_keys)
+    Q_FOREACH (const QString &key, all_keys)
     {
         if (key.contains(slash)) {
             QString group = key.section(slash, 0, 0);
@@ -508,7 +506,7 @@ QStringList Account::childKeys() const
     QStringList keys, all_keys;
 
     all_keys = allKeys();
-    Q_FOREACH (QString key, all_keys)
+    Q_FOREACH (const QString &key, all_keys)
     {
         if (!key.contains(slash))
             keys.append(key);
@@ -586,7 +584,7 @@ void Account::remove(const QString &key)
     {
         /* delete all keys in the group */
         QStringList keys = allKeys();
-        Q_FOREACH (QString key, keys)
+        Q_FOREACH (const QString &key, keys)
         {
             if (!key.isEmpty())
                 remove(key);
@@ -623,14 +621,11 @@ void Account::Private::account_store_cb(AgAccount *account,
                                         GAsyncResult *res,
                                         Account *self)
 {
-    TRACE() << "Saved accunt ID:" << account->id;
-
     GError *error = NULL;
     ag_account_store_finish(account, res, &error);
     if (error) {
         if (error->domain == G_IO_ERROR &&
             error->code == G_IO_ERROR_CANCELLED) {
-            TRACE() << "Account destroyed, operation cancelled";
         } else {
             Q_EMIT self->error(Error(error));
         }
